@@ -22,13 +22,15 @@ def generateCommentsGPT2(msg, num=1):
 
 def copyComment(post, comment):
     pyperclip.copy(comment)
-    print(f"[bold]Comment copied to clipboard, paste here: {post['link']} [/bold]")
 
 def getPosts(title='beaverconfessions', pages=5):
     posts = []
     for post in get_posts(title, pages=pages):
         new_post = {}
-        new_post['message'] = convert(post['post_text'])
+        if post['post_text'] is None: #sometimes it can return None. facebook-scraper does not guarantee 
+            new_post['message'] = ""
+        else:
+            new_post['message'] = convert(post['post_text'])
         new_post['link'] = post['post_url']
         new_post['id'] = post['post_id']
         posts.append(new_post)
